@@ -281,7 +281,7 @@ void CodeEditor::remark(int line){
 
 }
 
-void CodeEditor::toggleRemaks(){
+void CodeEditor::toggleRemarks(){
 QTextCursor cu=textCursor();
 cu.beginEditBlock();
 int start=0,end=0,hilf=0;
@@ -430,7 +430,7 @@ void  CodeEditor::contextMenuEvent(QContextMenuEvent *event) {
                          this, SLOT(selectInStructure()));
          a->setData(textCursor().selectedText());
 	 a=menu->addAction(QString("toggle remarks states of selected text"),
-			 this,SLOT(toggleRemaks()));
+			 this,SLOT(toggleRemarks()));
      }
      //...
      menu->exec(event->globalPos());
